.. -*- coding: utf-8 -*-

============================
  `aiotk`: asyncio toolkit
============================

Purpose
=======

This is a collection of asyncio-related utilities that I have found useful,
that I've used in at least two projects and that seem like they might be useful
to others.

Resources
=========

- Documentation: `aiotk on ReadTheDocs`_
- Official releases: `aiotk on PyPI`_
- Source code: `aiotk on GitHub`_

.. _`aiotk on ReadTheDocs`: http://aiotk.readthedocs.io/en/latest/
.. _`aiotk on PyPI`: https://pypi.org/project/aiotk/
.. _`aiotk on GitHub`: https://github.com/AndreLouisCaron/aiotk

Contributing
============

Nobody is paid to maintain this software, but we welcome pull requests!

License
=======

Licensed under the very permissive MIT license for maximum usage.
